=============================
django_eulasees
=============================

.. image:: https://badge.fury.io/py/django_eulasees.png
    :target: https://badge.fury.io/py/django_eulasees

.. image:: https://travis-ci.org/swfiua/django_eulasees.png?branch=master
    :target: https://travis-ci.org/swfiua/django_eulasees

.. image:: https://coveralls.io/repos/swfiua/django_eulasees/badge.png?branch=master
    :target: https://coveralls.io/r/swfiua/django_eulasees?branch=master

Team Bermuda django app for koding hackathon

Documentation
-------------

The full documentation is at https://django_eulasees.readthedocs.org.

Quickstart
----------

Install django_eulasees::

    pip install django_eulasees

Then use it in a project::

    import django_eulasees

Features
--------

* TODO
